<?php
//============================================================+
// File name   : rus.php
// Begin       : 2004-03-03
// Last Update : 2012-07-25
//
// Description : Language module for TCPDF
//               (contains translated texts)
//               Russian
//
// Author: Nicola Asuni
//
// (c) Copyright:
//               Nicola Asuni
//               Tecnick.com LTD
//               Manor Coach House, Church Hill
//               Aldershot, Hants, GU12 4RQ
//               UK
//               www.tecnick.com
//               info@tecnick.com
//============================================================+

/**
 * TCPDF language file (contains translated texts).
 * @package com.tecnick.tcpdf
 * @brief TCPDF language file: Russian
 * @author Nicola Asuni
 * @since 2004-03-03
 */

// Russian

global $l;
$l = Array();

// PAGE META DESCRIPTORS --------------------------------------

$l['a_meta_charset'] = 'UTF-8';
$l['a_meta_dir'] = 'ltr';
$l['a_meta_language'] = 'ru';

// TRANSLATIONS --------------------------------------
$l['w_page'] = 'страница';

//============================================================+
// END OF FILE
//============================================================+
